summaryrefslogtreecommitdiff
path: root/net
diff options
context:
space:
mode:
authorKiran Kumar Lokere <klokere@codeaurora.org>2018-01-18 11:57:29 -0800
committerAmar Singhal <asinghal@codeaurora.org>2018-02-06 11:44:16 -0800
commit2aa0bb3ac04d659292993423415a98a9b3cdda49 (patch)
tree6b77c47246ec3ca3b0f3495e01451d4c4227157c /net
parent31e37a680dcbb02ba41d17972dba0b298cf1983d (diff)
reg: qcom: call reg notifier during wiphy registration
Call reg notifier for self managed hints during wiphy registration. Call the notifier with last reg-domain request. CRs-Fixed: 2183721 Change-Id: I4fdc0a8fae94f774c4b923fba26a8eec1c96730d Signed-off-by: Kiran Kumar Lokere <klokere@codeaurora.org>
Diffstat (limited to 'net')
-rw-r--r--net/wireless/reg.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/net/wireless/reg.c b/net/wireless/reg.c
index f3fc9a36b473..02177062f57a 100644
--- a/net/wireless/reg.c
+++ b/net/wireless/reg.c
@@ -1760,11 +1760,13 @@ static void wiphy_update_regulatory(struct wiphy *wiphy,
if (ignore_reg_update(wiphy, initiator)) {
/*
* Regulatory updates set by CORE are ignored for custom
* regulatory cards. Let us notify the changes to the driver,
* as some drivers used this to restore its orig_* reg domain.
*/
- if (initiator == NL80211_REGDOM_SET_BY_CORE &&
- wiphy->regulatory_flags & REGULATORY_CUSTOM_REG)
+ if ((initiator == NL80211_REGDOM_SET_BY_CORE &&
+ wiphy->regulatory_flags & REGULATORY_CUSTOM_REG) ||
+ (wiphy->regulatory_flags & REGULATORY_WIPHY_SELF_MANAGED))
reg_call_notifier(wiphy, lr);
return;
}
@@ -1760,11 +1760,13 @@ static void wiphy_update_regulatory(struct wiphy *wiphy,
/*
* Regulatory updates set by CORE are ignored for custom
- * regulatory cards. Let us notify the changes to the driver,
+ * regulatory cards and for self managed regulatory.
+ * Let us notify the changes to the driver,
* as some drivers used this to restore its orig_* reg domain.
*/